/*  File: analyser-thrust.h
 *  Created by Zoltán Nagy on 14 January 2020.
 *  Modified by D. Soper on ....
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your opTion) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef __analyser_y23_h__
#define __analyser_y23_h__ 1


/*   project headers  */
#include <user.h>

/*   other includes   */



/*   It is not a library just a module. We can use using namespace...  */
using namespace std;
using namespace duct;
using namespace duct::distpoint;


/*   Narrowing the distbook template   */
using Dist1D = distbook<double, hist1d>;
using Dist1F = distbook<double, double>;


/*   
 *   This is the declaration of the analyser class.
 */
class UserY23 : public basic_user<epa, Dist1D, Dist1F>
{
  /*   useful aliases  */
  using Hist1D = Phys<Dist1D>;
  using Func1D = Phys<Dist1F>;

public:
  /*    constructors  (This uses chunks of 5M events for storing data)   */
  UserY23(const char *n, const duration_type& d = 2.0min) {
    this->param(n, d, 5000000);
  }
  
  
  /*   User defined init function. It is called once at the begining of the calculation.  */
  void initfunc();
  
  /*   The analyser routine. It analyses the events and fill the histograms.   */
  void userfunc(const shower_stage<epa>&, const shower_stage<epa>&, const shower_stage<epa>&);

  /*   Thrust function     */
  static double cambridge_y23(event<epa>);
};

#endif
